//  Element.setAttribute for names containing special characters
//
//  This module monkey-patches the browser builtin  *Element.prototype.setAttribute*
//  thereby allowing initial special characters in element attribute names.
//  We rename the original setAttribute to _setAttribute, before monkey-patching.
//
//  use:  
//          import 'vue-setattribute-extended'
//
//          element.setAttribute( '@foo',2 )       // now succeeds
//
//
//  genedronek 1/29/2019


install();

function install() {
    if (
        typeof Element == "function" && 
        typeof Element.prototype != "undefined" &&
        typeof Element.prototype.setAttribute == "function" ) {

        //  save once, the original definition
        if ( !Element.prototype._setAttribute )
            Element.prototype._setAttribute = Element.prototype.setAttribute;

        //  monkey patch setAttribute
        Element.prototype.setAttribute = setAttributeExtended;
    }
}

function setAttributeExtended(k,v) {

    // taste key, we intercept only extended names
    // otherwise we use original setAttribute
    return isAlphaKey( k )
            ? Element.prototype._setAttribute.call(this,k,v)
            : ATTRNODE(this,k,v)


	//  using css definition for attribute name
    function isAlphaKey( k ) {
        //return String(k).match( /^[a-z$_\.][a-z0-9\-_:\.]+$/i )
        return String(k).match( /^[-]?[a-z$_\.][a-z0-9$_:\.-]+$/i )
    }


	//  using DOM level 1 {get,set,clone}AttributeNode
    function ATTRNODE(ele,attr,value) {


        //  2 args ==> getter
        if ( arguments.length == 2 )
            return ele.getAttribute( attr );

        //  3 args ==> setter
        var div = ATTRNODE.div || ( ATTRNODE.div = document.createElement( "div" ));

        div.innerHTML = `<div ${attr} />`;  // have browser parse attr
        var child      = div.firstChild,
            attrNode   = child.getAttributeNode( attr ),
            attrCopy   = attrNode.cloneNode( true );
        attrCopy.value = value;
        //  finish using DOM level 1 setAttributeNode
        return ele.setAttributeNode( attrCopy )
    }
}
